summaryrefslogtreecommitdiff
path: root/dryad/user.go
diff options
context:
space:
mode:
Diffstat (limited to 'dryad/user.go')
-rw-r--r--dryad/user.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/dryad/user.go b/dryad/user.go
index ef80812..76cef73 100644
--- a/dryad/user.go
+++ b/dryad/user.go
@@ -137,8 +137,8 @@ func (bu *borutaUser) update() (err error) {
return
}
// generateAndInstallKey calls generateAndInstallKey with parameters retrieved from the user field
// of borutaUser structure. This filed must be set before call to this function by update() method.
-func (bu *borutaUser) generateAndInstallKey(key ssh.PublicKey) error {
+func (bu *borutaUser) installKey(key *ssh.PublicKey) error {
return installPublicKey(key, bu.user.HomeDir, bu.user.Uid, bu.user.Gid)
}
@@ -137,8 +137,8 @@ func (bu *borutaUser) update() (err error) {
return
}
-// generateAndInstallKey calls generateAndInstallKey with parameters retrieved from the user field
+// installKey calls installPublicKey with parameters retrieved from the user field
// of borutaUser structure. This filed must be set before call to this function by update() method.